@@ -1,9 +1,9 @@
 package Complete::Bash;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-16'; # DATE
+our $DATE = '2021-07-24'; # DATE
 our $DIST = 'Complete-Bash'; # DIST
-our $VERSION = '0.335'; # VERSION
+our $VERSION = '0.336'; # VERSION
 
 use 5.010001;
 use strict;
@@ -697,6 +697,7 @@ sub format_completion {
     }
 
   PASS_TO_FZF: {
+        last if $ENV{INSIDE_EMACS};
         last unless $ENV{COMPLETE_BASH_FZF};
         my $items = $ENV{COMPLETE_BASH_FZF_ITEMS} // 100;
         last unless @words >= $items;
@@ -759,7 +760,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.335 of Complete::Bash (from Perl distribution Complete-Bash), released on 2020-04-16.
+This document describes version 0.336 of Complete::Bash (from Perl distribution Complete-Bash), released on 2021-07-24.
 
 =head1 DESCRIPTION
 
@@ -919,7 +920,7 @@ Return value: Formatted string (or array, if `as` is set to `array`) (str|array)
 
 Usage:
 
- join_wordbreak_words() -> [status, msg, payload, meta]
+ join_wordbreak_words() -> [$status_code, $reason, $payload, \%result_meta]
 
 Post-process parse_cmdline() result by joining some words.
 
@@ -947,12 +948,12 @@ No arguments.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1149,6 +1150,8 @@ default, large is defined as having at least 100 items (same bash's
 C<completion-query-items> setting). This can be configured via
 L</COMPLETE_BASH_FZF_ITEMS>.
 
+Will not pass to fzf if inside emacs (C<INSIDE_EMACS> environment is true).
+
 =head2 COMPLETE_BASH_FZF_ITEMS
 
 Uint. Default 100. The minimum number of items to trigger passing completion
@@ -1229,9 +1232,25 @@ L<https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion.htm
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mary Ehlers Steven Haryanto
+
+=over 4
+
+=item *
+
+Mary Ehlers <regina.verb.ae@gmail.com>
+
+=item *
+
+Steven Haryanto <sharyanto@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
